"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from lambdadb import utils
from lambdadb.types import BaseModel
from typing import Optional


class TooManyRequestsErrorData(BaseModel):
    message: Optional[str] = None


class TooManyRequestsError(Exception):
    data: TooManyRequestsErrorData

    def __init__(self, data: TooManyRequestsErrorData):
        self.data = data

    def __str__(self) -> str:
        return utils.marshal_json(self.data, TooManyRequestsErrorData)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module

if TYPE_CHECKING:
    from .bulkupsertdocsop import (
        BulkUpsertDocsRequest,
        BulkUpsertDocsRequestBody,
        BulkUpsertDocsRequestBodyTypedDict,
        BulkUpsertDocsRequestTypedDict,
        BulkUpsertDocsResponse,
        BulkUpsertDocsResponseTypedDict,
    )
    from .collectionresponse import CollectionResponse, CollectionResponseTypedDict
    from .createcollectionop import (
        CreateCollectionRequest,
        CreateCollectionRequestBody,
        CreateCollectionRequestBodyTypedDict,
        CreateCollectionRequestTypedDict,
    )
    from .deletecollectionop import (
        DeleteCollectionRequest,
        DeleteCollectionRequestTypedDict,
        DeleteCollectionResponse,
        DeleteCollectionResponseTypedDict,
    )
    from .deletedocsop import (
        DeleteDocsRequest,
        DeleteDocsRequestBody,
        DeleteDocsRequestBodyTypedDict,
        DeleteDocsRequestTypedDict,
        DeleteDocsResponse,
        DeleteDocsResponseTypedDict,
        Filter,
        FilterTypedDict,
    )
    from .fetchdocsop import (
        FetchDocsDoc,
        FetchDocsDocDoc,
        FetchDocsDocDocTypedDict,
        FetchDocsDocTypedDict,
        FetchDocsRequest,
        FetchDocsRequestBody,
        FetchDocsRequestBodyTypedDict,
        FetchDocsRequestTypedDict,
        FetchDocsResponse,
        FetchDocsResponseTypedDict,
    )
    from .getbulkupsertdocsop import (
        GetBulkUpsertDocsRequest,
        GetBulkUpsertDocsRequestTypedDict,
        GetBulkUpsertDocsResponse,
        GetBulkUpsertDocsResponseTypedDict,
        GetBulkUpsertDocsType,
        HTTPMethod,
    )
    from .getcollectionop import GetCollectionRequest, GetCollectionRequestTypedDict
    from .indexconfigs_union import (
        Analyzer,
        IndexConfigs,
        IndexConfigsText,
        IndexConfigsTextTypedDict,
        IndexConfigsTypedDict,
        IndexConfigsUnion,
        IndexConfigsUnionTypedDict,
        IndexConfigsVector,
        IndexConfigsVectorTypedDict,
        Similarity,
        Type,
        TypeText,
        TypeVector,
    )
    from .listcollectionsop import (
        ListCollectionsRequest,
        ListCollectionsRequestTypedDict,
        ListCollectionsResponse,
        ListCollectionsResponseTypedDict,
    )
    from .querycollectionop import (
        Query,
        QueryCollectionDoc,
        QueryCollectionDocDoc,
        QueryCollectionDocDocTypedDict,
        QueryCollectionDocTypedDict,
        QueryCollectionRequest,
        QueryCollectionRequestBody,
        QueryCollectionRequestBodyTypedDict,
        QueryCollectionRequestTypedDict,
        QueryCollectionResponse,
        QueryCollectionResponseTypedDict,
        QueryTypedDict,
        Sort,
        SortTypedDict,
    )
    from .security import Security, SecurityTypedDict
    from .status import Status
    from .updatecollectionop import (
        UpdateCollectionRequest,
        UpdateCollectionRequestBody,
        UpdateCollectionRequestBodyTypedDict,
        UpdateCollectionRequestTypedDict,
    )
    from .updatedocsop import (
        UpdateDocsDoc,
        UpdateDocsDocTypedDict,
        UpdateDocsRequest,
        UpdateDocsRequestBody,
        UpdateDocsRequestBodyTypedDict,
        UpdateDocsRequestTypedDict,
        UpdateDocsResponse,
        UpdateDocsResponseTypedDict,
    )
    from .upsertdocsop import (
        UpsertDocsDoc,
        UpsertDocsDocTypedDict,
        UpsertDocsRequest,
        UpsertDocsRequestBody,
        UpsertDocsRequestBodyTypedDict,
        UpsertDocsRequestTypedDict,
        UpsertDocsResponse,
        UpsertDocsResponseTypedDict,
    )

__all__ = [
    "Analyzer",
    "BulkUpsertDocsRequest",
    "BulkUpsertDocsRequestBody",
    "BulkUpsertDocsRequestBodyTypedDict",
    "BulkUpsertDocsRequestTypedDict",
    "BulkUpsertDocsResponse",
    "BulkUpsertDocsResponseTypedDict",
    "CollectionResponse",
    "CollectionResponseTypedDict",
    "CreateCollectionRequest",
    "CreateCollectionRequestBody",
    "CreateCollectionRequestBodyTypedDict",
    "CreateCollectionRequestTypedDict",
    "DeleteCollectionRequest",
    "DeleteCollectionRequestTypedDict",
    "DeleteCollectionResponse",
    "DeleteCollectionResponseTypedDict",
    "DeleteDocsRequest",
    "DeleteDocsRequestBody",
    "DeleteDocsRequestBodyTypedDict",
    "DeleteDocsRequestTypedDict",
    "DeleteDocsResponse",
    "DeleteDocsResponseTypedDict",
    "FetchDocsDoc",
    "FetchDocsDocDoc",
    "FetchDocsDocDocTypedDict",
    "FetchDocsDocTypedDict",
    "FetchDocsRequest",
    "FetchDocsRequestBody",
    "FetchDocsRequestBodyTypedDict",
    "FetchDocsRequestTypedDict",
    "FetchDocsResponse",
    "FetchDocsResponseTypedDict",
    "Filter",
    "FilterTypedDict",
    "GetBulkUpsertDocsRequest",
    "GetBulkUpsertDocsRequestTypedDict",
    "GetBulkUpsertDocsResponse",
    "GetBulkUpsertDocsResponseTypedDict",
    "GetBulkUpsertDocsType",
    "GetCollectionRequest",
    "GetCollectionRequestTypedDict",
    "HTTPMethod",
    "IndexConfigs",
    "IndexConfigsText",
    "IndexConfigsTextTypedDict",
    "IndexConfigsTypedDict",
    "IndexConfigsUnion",
    "IndexConfigsUnionTypedDict",
    "IndexConfigsVector",
    "IndexConfigsVectorTypedDict",
    "ListCollectionsRequest",
    "ListCollectionsRequestTypedDict",
    "ListCollectionsResponse",
    "ListCollectionsResponseTypedDict",
    "Query",
    "QueryCollectionDoc",
    "QueryCollectionDocDoc",
    "QueryCollectionDocDocTypedDict",
    "QueryCollectionDocTypedDict",
    "QueryCollectionRequest",
    "QueryCollectionRequestBody",
    "QueryCollectionRequestBodyTypedDict",
    "QueryCollectionRequestTypedDict",
    "QueryCollectionResponse",
    "QueryCollectionResponseTypedDict",
    "QueryTypedDict",
    "Security",
    "SecurityTypedDict",
    "Similarity",
    "Sort",
    "SortTypedDict",
    "Status",
    "Type",
    "TypeText",
    "TypeVector",
    "UpdateCollectionRequest",
    "UpdateCollectionRequestBody",
    "UpdateCollectionRequestBodyTypedDict",
    "UpdateCollectionRequestTypedDict",
    "UpdateDocsDoc",
    "UpdateDocsDocTypedDict",
    "UpdateDocsRequest",
    "UpdateDocsRequestBody",
    "UpdateDocsRequestBodyTypedDict",
    "UpdateDocsRequestTypedDict",
    "UpdateDocsResponse",
    "UpdateDocsResponseTypedDict",
    "UpsertDocsDoc",
    "UpsertDocsDocTypedDict",
    "UpsertDocsRequest",
    "UpsertDocsRequestBody",
    "UpsertDocsRequestBodyTypedDict",
    "UpsertDocsRequestTypedDict",
    "UpsertDocsResponse",
    "UpsertDocsResponseTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "BulkUpsertDocsRequest": ".bulkupsertdocsop",
    "BulkUpsertDocsRequestBody": ".bulkupsertdocsop",
    "BulkUpsertDocsRequestBodyTypedDict": ".bulkupsertdocsop",
    "BulkUpsertDocsRequestTypedDict": ".bulkupsertdocsop",
    "BulkUpsertDocsResponse": ".bulkupsertdocsop",
    "BulkUpsertDocsResponseTypedDict": ".bulkupsertdocsop",
    "CollectionResponse": ".collectionresponse",
    "CollectionResponseTypedDict": ".collectionresponse",
    "CreateCollectionRequest": ".createcollectionop",
    "CreateCollectionRequestBody": ".createcollectionop",
    "CreateCollectionRequestBodyTypedDict": ".createcollectionop",
    "CreateCollectionRequestTypedDict": ".createcollectionop",
    "DeleteCollectionRequest": ".deletecollectionop",
    "DeleteCollectionRequestTypedDict": ".deletecollectionop",
    "DeleteCollectionResponse": ".deletecollectionop",
    "DeleteCollectionResponseTypedDict": ".deletecollectionop",
    "DeleteDocsRequest": ".deletedocsop",
    "DeleteDocsRequestBody": ".deletedocsop",
    "DeleteDocsRequestBodyTypedDict": ".deletedocsop",
    "DeleteDocsRequestTypedDict": ".deletedocsop",
    "DeleteDocsResponse": ".deletedocsop",
    "DeleteDocsResponseTypedDict": ".deletedocsop",
    "Filter": ".deletedocsop",
    "FilterTypedDict": ".deletedocsop",
    "FetchDocsDoc": ".fetchdocsop",
    "FetchDocsDocDoc": ".fetchdocsop",
    "FetchDocsDocDocTypedDict": ".fetchdocsop",
    "FetchDocsDocTypedDict": ".fetchdocsop",
    "FetchDocsRequest": ".fetchdocsop",
    "FetchDocsRequestBody": ".fetchdocsop",
    "FetchDocsRequestBodyTypedDict": ".fetchdocsop",
    "FetchDocsRequestTypedDict": ".fetchdocsop",
    "FetchDocsResponse": ".fetchdocsop",
    "FetchDocsResponseTypedDict": ".fetchdocsop",
    "GetBulkUpsertDocsRequest": ".getbulkupsertdocsop",
    "GetBulkUpsertDocsRequestTypedDict": ".getbulkupsertdocsop",
    "GetBulkUpsertDocsResponse": ".getbulkupsertdocsop",
    "GetBulkUpsertDocsResponseTypedDict": ".getbulkupsertdocsop",
    "GetBulkUpsertDocsType": ".getbulkupsertdocsop",
    "HTTPMethod": ".getbulkupsertdocsop",
    "GetCollectionRequest": ".getcollectionop",
    "GetCollectionRequestTypedDict": ".getcollectionop",
    "Analyzer": ".indexconfigs_union",
    "IndexConfigs": ".indexconfigs_union",
    "IndexConfigsText": ".indexconfigs_union",
    "IndexConfigsTextTypedDict": ".indexconfigs_union",
    "IndexConfigsTypedDict": ".indexconfigs_union",
    "IndexConfigsUnion": ".indexconfigs_union",
    "IndexConfigsUnionTypedDict": ".indexconfigs_union",
    "IndexConfigsVector": ".indexconfigs_union",
    "IndexConfigsVectorTypedDict": ".indexconfigs_union",
    "Similarity": ".indexconfigs_union",
    "Type": ".indexconfigs_union",
    "TypeText": ".indexconfigs_union",
    "TypeVector": ".indexconfigs_union",
    "ListCollectionsRequest": ".listcollectionsop",
    "ListCollectionsRequestTypedDict": ".listcollectionsop",
    "ListCollectionsResponse": ".listcollectionsop",
    "ListCollectionsResponseTypedDict": ".listcollectionsop",
    "Query": ".querycollectionop",
    "QueryCollectionDoc": ".querycollectionop",
    "QueryCollectionDocDoc": ".querycollectionop",
    "QueryCollectionDocDocTypedDict": ".querycollectionop",
    "QueryCollectionDocTypedDict": ".querycollectionop",
    "QueryCollectionRequest": ".querycollectionop",
    "QueryCollectionRequestBody": ".querycollectionop",
    "QueryCollectionRequestBodyTypedDict": ".querycollectionop",
    "QueryCollectionRequestTypedDict": ".querycollectionop",
    "QueryCollectionResponse": ".querycollectionop",
    "QueryCollectionResponseTypedDict": ".querycollectionop",
    "QueryTypedDict": ".querycollectionop",
    "Sort": ".querycollectionop",
    "SortTypedDict": ".querycollectionop",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "Status": ".status",
    "UpdateCollectionRequest": ".updatecollectionop",
    "UpdateCollectionRequestBody": ".updatecollectionop",
    "UpdateCollectionRequestBodyTypedDict": ".updatecollectionop",
    "UpdateCollectionRequestTypedDict": ".updatecollectionop",
    "UpdateDocsDoc": ".updatedocsop",
    "UpdateDocsDocTypedDict": ".updatedocsop",
    "UpdateDocsRequest": ".updatedocsop",
    "UpdateDocsRequestBody": ".updatedocsop",
    "UpdateDocsRequestBodyTypedDict": ".updatedocsop",
    "UpdateDocsRequestTypedDict": ".updatedocsop",
    "UpdateDocsResponse": ".updatedocsop",
    "UpdateDocsResponseTypedDict": ".updatedocsop",
    "UpsertDocsDoc": ".upsertdocsop",
    "UpsertDocsDocTypedDict": ".upsertdocsop",
    "UpsertDocsRequest": ".upsertdocsop",
    "UpsertDocsRequestBody": ".upsertdocsop",
    "UpsertDocsRequestBodyTypedDict": ".upsertdocsop",
    "UpsertDocsRequestTypedDict": ".upsertdocsop",
    "UpsertDocsResponse": ".upsertdocsop",
    "UpsertDocsResponseTypedDict": ".upsertdocsop",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from lambdadb.types import BaseModel
from lambdadb.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UpdateDocsDocTypedDict(TypedDict):
    pass


class UpdateDocsDoc(BaseModel):
    pass


class UpdateDocsRequestBodyTypedDict(TypedDict):
    docs: List[UpdateDocsDocTypedDict]
    r"""A list of documents to update. Each document must contain 'id' field to be updated."""


class UpdateDocsRequestBody(BaseModel):
    docs: List[UpdateDocsDoc]
    r"""A list of documents to update. Each document must contain 'id' field to be updated."""


class UpdateDocsRequestTypedDict(TypedDict):
    project_name: str
    r"""Project name."""
    collection_name: str
    r"""Collection name."""
    request_body: UpdateDocsRequestBodyTypedDict


class UpdateDocsRequest(BaseModel):
    project_name: Annotated[
        str,
        pydantic.Field(alias="projectName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Project name."""

    collection_name: Annotated[
        str,
        pydantic.Field(alias="collectionName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Collection name."""

    request_body: Annotated[
        UpdateDocsRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UpdateDocsResponseTypedDict(TypedDict):
    r"""Update request accepted."""

    message: NotRequired[str]


class UpdateDocsResponse(BaseModel):
    r"""Update request accepted."""

    message: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from lambdadb.types import BaseModel
from lambdadb.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UpsertDocsDocTypedDict(TypedDict):
    pass


class UpsertDocsDoc(BaseModel):
    pass


class UpsertDocsRequestBodyTypedDict(TypedDict):
    docs: List[UpsertDocsDocTypedDict]
    r"""A list of documents to upsert."""


class UpsertDocsRequestBody(BaseModel):
    docs: List[UpsertDocsDoc]
    r"""A list of documents to upsert."""


class UpsertDocsRequestTypedDict(TypedDict):
    project_name: str
    r"""Project name."""
    collection_name: str
    r"""Collection name."""
    request_body: UpsertDocsRequestBodyTypedDict


class UpsertDocsRequest(BaseModel):
    project_name: Annotated[
        str,
        pydantic.Field(alias="projectName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Project name."""

    collection_name: Annotated[
        str,
        pydantic.Field(alias="collectionName"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Collection name."""

    request_body: Annotated[
        UpsertDocsRequestBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]


class UpsertDocsResponseTypedDict(TypedDict):
    r"""Upsert request accepted."""

    message: NotRequired[str]


class UpsertDocsResponse(BaseModel):
    r"""Upsert request accepted."""

    message: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .indexconfigs_union import IndexConfigsUnion, IndexConfigsUnionTypedDict
from .status import Status
from lambdadb.types import BaseModel
import pydantic
from typing import Dict, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CollectionResponseTypedDict(TypedDict):
    project_name: NotRequired[str]
    r"""Project name."""
    collection_name: NotRequired[str]
    r"""Collection name."""
    index_configs: NotRequired[Dict[str, IndexConfigsUnionTypedDict]]
    num_docs: NotRequired[int]
    r"""Total number of documents."""
    source_project_name: NotRequired[str]
    r"""Source project name."""
    source_collection_name: NotRequired[str]
    r"""Source collection name."""
    source_collection_version_id: NotRequired[str]
    r"""Source collection version."""
    collection_status: NotRequired[Status]
    r"""Status"""


class CollectionResponse(BaseModel):
    project_name: Annotated[Optional[str], pydantic.Field(alias="projectName")] = None
    r"""Project name."""

    collection_name: Annotated[
        Optional[str], pydantic.Field(alias="collectionName")
    ] = None
    r"""Collection name."""

    index_configs: Annotated[
        Optional[Dict[str, IndexConfigsUnion]], pydantic.Field(alias="indexConfigs")
    ] = None

    num_docs: Annotated[Optional[int], pydantic.Field(alias="numDocs")] = None
    r"""Total number of documents."""

    source_project_name: Annotated[
        Optional[str], pydantic.Field(alias="sourceProjectName")
    ] = None
    r"""Source project name."""

    source_collection_name: Annotated[
        Optional[str], pydantic.Field(alias="sourceCollectionName")
    ] = None
    r"""Source collection name."""

    source_collection_version_id: Annotated[
        Optional[str], pydantic.Field(alias="sourceCollectionVersionId")
    ] = None
    r"""Source collection version."""

    collection_status: Annotated[
        Optional[Status], pydantic.Field(alias="collectionStatus")
    ] = None
    r"""Status"""
